import {Dimensions, StyleSheet, Text, View} from 'react-native';
import React from 'react';
import {Button} from 'react-native-paper';
import Slider from '@react-native-community/slider';

const renderIconForSetting = setting => {
  switch (setting.settingsKey) {
    case 'torch':
      return setting.value ? 'flashlight' : 'flashlight-off';
    case 'lowLightBoost':
      return setting.value ? 'floor-lamp' : 'floor-lamp-outline';
    case 'highQualityPhoto':
      return setting.value ? 'high-definition-box' : 'high-definition';
    case 'hdr':
      return setting.value ? 'hdr' : 'hdr-off';
    default:
      return '';
  }
};

const RenderCameraSetting = props => {
  if (typeof props.setting.value === 'boolean') {
    return (
      <Button
        icon={renderIconForSetting(props.setting)}
        mode="contained"
        style={styles.toggle}
        textColor="#000"
        onPress={() => {
          props.setSetting({
            ...props.setting,
            value: !props.setting.value,
          });
        }}>
        {props.setting.label}
      </Button>
    );
  }
  return (
    <View style={styles.sliderContainer}>
      <Slider
        step={props.setting.step}
        style={styles.slider}
        value={props.setting.value}
        minimumValue={props.setting.min}
        maximumValue={props.setting.max}
        minimumTrackTintColor="white"
        maximumTrackTintColor="grey"
        onValueChange={value =>
          props.setSetting({
            ...props.setting,
            value,
          })
        }
      />
      <Text style={styles.sliderText}>
        {props.setting.settingsKey} {props.setting.value}
      </Text>
    </View>
  );
};

const CameraSettings = props => {
  return (
    <View style={styles.root}>
      {props.settings.map(setting => (
        <RenderCameraSetting
          setting={setting}
          setSetting={props.setSetting}
          key={setting.settingsKey}
        />
      ))}
    </View>
  );
};

export default CameraSettings;

const styles = StyleSheet.create({
  root: {
    width: Dimensions.get('window').width - 50,
    height: Dimensions.get('window').width - 50,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    zIndex: 100,
    elevation: 100,
    position: 'absolute',
    alignSelf: 'center',
    padding: 10,
    borderRadius: 30,
    marginTop: 150,
    flexDirection: 'row',
    flexWrap: 'wrap',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  sliderContainer: {
    width: '100%',
    marginBottom: 25,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  slider: {
    width: '70%',
  },
  sliderText: {
    textTransform: 'uppercase',
    color: 'white',
  },
  toggle: {
    width: '48%',
    marginBottom: 25,
    backgroundColor: 'white',
  },
});
