/* eslint-disable react-hooks/exhaustive-deps */
import {Animated} from 'react-native';
import React, {
  forwardRef,
  useEffect,
  useImperativeHandle,
  useRef,
  useState,
} from 'react';

const Fade = forwardRef(
  (
    {children, onFadeStart = () => {}, onFadeEnd = () => {}, config = {}},
    ref,
  ) => {
    const {duration = 1000, startOpacity = 0, endOpacity = 1} = config;
    // once the component runs it initial transition
    // it stores the value to be used as initial point for the next transition
    const [reUseOffset, setReUseOffset] = useState();

    const animation = useRef(new Animated.Value(startOpacity)).current;

    // used to trigger the initial transition on mount
    useEffect(() => {
      Animated.timing(animation, {
        toValue: endOpacity,
        duration: duration,
        useNativeDriver: true,
      }).start(onFadeEnd);
      onFadeStart();
      setReUseOffset(endOpacity);
    }, []);

    useImperativeHandle(ref, () => ({
      // used to re-trigger the transition after initial transition
      triggerAnimation(fadeTo) {
        if (reUseOffset) {
          animation.setValue(reUseOffset);
        }
        Animated.timing(animation, {
          toValue: fadeTo,
          duration: duration,
          useNativeDriver: true,
        }).start(onFadeEnd);
        onFadeStart();
        setReUseOffset(fadeTo);
      },
    }));

    return (
      <Animated.View style={{opacity: animation}}>{children}</Animated.View>
    );
  },
);

export default Fade;
