import {Animated} from 'react-native';
import React, {useEffect, useImperativeHandle, useRef, useState} from 'react';

const Scale = React.forwardRef(
  (
    {children, onScaleStart = () => {}, onScaleEnd = () => {}, config = {}},
    ref,
  ) => {
    const {duration = 1000, startScale = 1, endScale = 1.5} = config;
    // once the component runs it initial transition
    // it stores the value to be used as initial point for the next transition
    const [reUseOffset, setReUseOffset] = useState();

    const animation = useRef(new Animated.Value(startScale)).current;

    // used to trigger the initial transition on mount
    useEffect(() => {
      Animated.timing(animation, {
        toValue: endScale,
        duration: duration,
        useNativeDriver: true,
      }).start(onScaleEnd);
      onScaleStart();
      setReUseOffset(endScale);
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);

    useImperativeHandle(ref, () => ({
      // used to re-trigger the transition after initial transition
      triggerAnimation(scaleTo) {
        if (reUseOffset) {
          animation.setValue(reUseOffset);
        }
        Animated.timing(animation, {
          toValue: scaleTo,
          duration: duration,
          useNativeDriver: true,
        }).start(onScaleEnd);
        onScaleStart();
        setReUseOffset(scaleTo);
      },
    }));

    return (
      <Animated.View
        style={{
          transform: [
            {
              scale: animation,
            },
          ],
        }}>
        {children}
      </Animated.View>
    );
  },
);

export default Scale;
